@@ -186,6 +186,9 @@ class TaskRunner(ABC):
                 AgentDisconnectedError,
                 AgentShutdownError,
             ):
+                if onboarding_agent.get_status() not in AgentState.complete():
+                    # Absent agents at this stage should be disconnected
+                    onboarding_agent.update_status(AgentState.STATUS_DISCONNECT)
                 self.cleanup_onboarding(onboarding_agent)
             except Exception as e:
                 logger.exception(
@@ -298,7 +301,13 @@ class TaskRunner(ABC):
                 agent.update_status(AgentState.STATUS_COMPLETED)
                 agent.mark_done()
 
-            self.shared_state.on_unit_submitted(unit)
+            try:
+                self.shared_state.on_unit_submitted(unit)
+            except Exception as e:
+                logger.exception(
+                    f"Unhandled exception in on_unit_submitted for {unit}",
+                    exc_info=True,
+                )
             del self.running_units[unit.db_id]
 
             self._cleanup_special_units(unit, agent)
@@ -379,7 +388,13 @@ class TaskRunner(ABC):
                     agent.mark_done()
 
             for unit in assignment.get_units():
-                self.shared_state.on_unit_submitted(unit)
+                try:
+                    self.shared_state.on_unit_submitted(unit)
+                except Exception as e:
+                    logger.exception(
+                        f"Unhandled exception in on_unit_submitted for {unit}",
+                        exc_info=True,
+                    )
             del self.running_assignments[assignment.db_id]
 
             # Clear reservations
