@@ -16,8 +16,11 @@ from typing import (
 from mephisto.abstractions.blueprint import BlueprintMixin
 from dataclasses import dataclass, field
 from omegaconf import MISSING, DictConfig
-from mephisto.data_model.qualification import make_qualification_dict, QUAL_NOT_EXIST
-from mephisto.operations.utils import find_or_create_qualification
+from mephisto.data_model.qualification import QUAL_NOT_EXIST
+from mephisto.utils.qualifications import (
+    make_qualification_dict,
+    find_or_create_qualification,
+)
 
 if TYPE_CHECKING:
     from mephisto.abstractions.blueprint import SharedTaskState
@@ -144,6 +147,12 @@ class OnboardingRequired(BlueprintMixin):
             db, self.onboarding_failed_name
         )
 
+    @classmethod
+    def clear_onboarding(self, worker: "Worker", qualification_name: str):
+        worker.revoke_qualification(qualification_name)
+        if qualification_name is not None:
+            worker.revoke_crowd_qualification(self.get_failed_qual(qualification_name))
+
     def get_onboarding_data(self, worker_id: str) -> Dict[str, Any]:
         """
         If the onboarding task on the frontend requires any specialized data, the blueprint
