@@ -21,8 +21,11 @@ import types
 from mephisto.abstractions.blueprint import BlueprintMixin
 from dataclasses import dataclass, field
 from omegaconf import MISSING, DictConfig
-from mephisto.data_model.qualification import make_qualification_dict, QUAL_NOT_EXIST
-from mephisto.operations.utils import find_or_create_qualification
+from mephisto.data_model.qualification import QUAL_NOT_EXIST
+from mephisto.utils.qualifications import (
+    make_qualification_dict,
+    find_or_create_qualification,
+)
 
 
 if TYPE_CHECKING:
@@ -115,7 +118,9 @@ class ScreenTaskRequired(BlueprintMixin):
         self.use_screening_task = args.blueprint.get("use_screening_task", False)
         if not self.use_screening_task:
             return
-
+        assert (
+            args.blueprint.get("use_golds") is not True
+        ), "Gold units currently cannot be used with screening units"
         # Runs that are using a qualification task should be able to assign
         # a specially generated unit to unqualified workers
         self.passed_qualification_name = args.blueprint.passed_qualification_name
@@ -165,6 +170,13 @@ class ScreenTaskRequired(BlueprintMixin):
                 "Must provide a generator function to SharedTaskState.screening_data_factory if "
                 "you want to generate screening tasks on the fly, or False if you can screen on any task "
             )
+            assert (
+                max_screening_units > 0
+            ), "max_screening_units must be greater than zero if using a screening_data_factory"
+        else:
+            assert (
+                max_screening_units == 0
+            ), "max_screening_units must be zero if not using a screening_data_factory"
 
     def worker_needs_screening(self, worker: "Worker") -> bool:
         """Workers that are able to access the task (not blocked) but are not passed need qualification"""
@@ -202,11 +214,17 @@ class ScreenTaskRequired(BlueprintMixin):
         failed_qualification_name = args.blueprint.block_qualification
 
         def _wrapped_validate(unit):
-            if unit.unit_index >= 0:
+            if args.blueprint.max_screening_units > 0 and unit.unit_index >= 0:
                 return  # We only run validation on the validatable units
-
-            validation_result = screen_unit(unit)
             agent = unit.get_assigned_agent()
+            if agent is None:
+                return  # Cannot validate a unit with no agent
+            if (
+                args.blueprint.max_screening_units == 0
+                and agent.get_worker().is_qualified(passed_qualification_name)
+            ):
+                return  # Do not run validation if screening with regular tasks and worker is already qualified
+            validation_result = screen_unit(unit)
             if validation_result is True:
                 agent.get_worker().grant_qualification(passed_qualification_name)
             elif validation_result is False:
