@@ -24,8 +24,11 @@ import traceback
 from mephisto.abstractions.blueprint import BlueprintMixin, AgentState
 from dataclasses import dataclass, field
 from omegaconf import MISSING, DictConfig
-from mephisto.data_model.qualification import make_qualification_dict, QUAL_NOT_EXIST
-from mephisto.operations.utils import find_or_create_qualification
+from mephisto.data_model.qualification import QUAL_NOT_EXIST
+from mephisto.utils.qualifications import (
+    make_qualification_dict,
+    find_or_create_qualification,
+)
 from mephisto.operations.task_launcher import GOLD_UNIT_INDEX
 
 
@@ -34,9 +37,10 @@ if TYPE_CHECKING:
     from mephisto.data_model.unit import Unit
     from mephisto.data_model.packet import Packet
     from mephisto.data_model.worker import Worker
+    from mephisto.abstractions.blueprint import SharedTaskState
     from argparse import _ArgumentGroup as ArgumentGroup
 
-from mephisto.operations.logger_core import get_logger
+from mephisto.utils.logger_core import get_logger
 
 logger = get_logger(name=__name__)
 
@@ -49,6 +53,16 @@ class UseGoldUnitArgs:
             "help": ("Basename for a qualification that tracks gold completion rates")
         },
     )
+    max_gold_units: int = field(
+        default=MISSING,
+        metadata={
+            "help": (
+                "The maximum number of gold units that can be launched "
+                "with this batch, specified to limit the number of golds "
+                "you may need to pay out for."
+            )
+        },
+    )
     use_golds: bool = field(
         default=False,
         metadata={"help": ("Whether or not to use gold tasks in this run.")},
@@ -57,7 +71,7 @@ class UseGoldUnitArgs:
         default=1,
         metadata={
             "help": (
-                "Minimum golds a worker needs to complete before " "getting real units."
+                "Minimum golds a worker needs to complete before getting real units."
             )
         },
     )
@@ -153,7 +167,7 @@ class UseGoldUnit(BlueprintMixin):
     Compositional class for blueprints that want to inject gold units
     into worker queues.
 
-    # TODO add support for adding gold subunits
+    # TODO(#97) add support for adding gold subunits
     """
 
     ArgsMixin = UseGoldUnitArgs
@@ -163,8 +177,11 @@ class UseGoldUnit(BlueprintMixin):
         self,
         task_run: "TaskRun",
         args: "DictConfig",
-        shared_state: "GoldUnitSharedState",
+        shared_state: "SharedTaskState",
     ) -> None:
+        assert isinstance(
+            shared_state, GoldUnitSharedState
+        ), f"Must use GoldUnitSharedState with this mixin, found {shared_state}"
         return self.init_gold_config(task_run, args, shared_state)
 
     def init_gold_config(
@@ -191,6 +208,8 @@ class UseGoldUnit(BlueprintMixin):
 
         self.min_golds = args.blueprint.min_golds
         self.max_incorrect_golds = args.blueprint.max_incorrect_golds
+        self.gold_units_launched = 0
+        self.gold_unit_cap = args.blueprint.max_gold_units
 
         find_or_create_qualification(task_run.db, self.golds_correct_qual_name)
         find_or_create_qualification(task_run.db, self.golds_failed_qual_name)
@@ -206,6 +225,15 @@ class UseGoldUnit(BlueprintMixin):
             "Can only run this task type with one allowed concurrent unit at a time per worker, to ensure "
             "golds are completed in order."
         )
+        assert (
+            args.blueprint.get("use_screening_task") is not True
+        ), "Gold units currently cannot be used with screening units"
+        max_gold_units = args.blueprint.max_gold_units
+        assert max_gold_units is not None, (
+            "You must supply a blueprint.max_gold_units argument to set the maximum number of "
+            "additional units you will pay out for evaluating on gold units. Note that you "
+            "do pay for gold units, they are just like any other units."
+        )
         gold_qualification_base = args.blueprint.gold_qualification_base
         assert (
             gold_qualification_base is not None
@@ -215,7 +243,7 @@ class UseGoldUnit(BlueprintMixin):
             "You must supply a get_gold_for_worker generator in your SharedTaskState to use "
             "gold units units."
         )
-        # TODO it would be nice to test that `get_gold_for_worker` actually returns a task when
+        # TODO(#97) it would be nice to test that `get_gold_for_worker` actually returns a task when
         # given a worker
 
     @staticmethod
@@ -250,6 +278,9 @@ class UseGoldUnit(BlueprintMixin):
             completed_units, correct_units, incorrect_units, self.max_incorrect_golds
         ):
             return False
+        if correct_units >= self.min_golds:
+            if self.gold_units_launched >= self.gold_unit_cap:
+                return False  # they qualify, but we don't have golds to launch
         return self.worker_needs_gold(
             completed_units, correct_units, incorrect_units, self.min_golds
         )
@@ -265,11 +296,16 @@ class UseGoldUnit(BlueprintMixin):
             completed_units, correct_units, incorrect_units, self.max_incorrect_golds
         ):
             worker.grant_qualification(self.disqualified_qual_name)
+            return True
+        return False
 
     def get_gold_unit_data_for_worker(
         self, worker: "Worker"
     ) -> Optional[Dict[str, Any]]:
+        if self.gold_units_launched >= self.gold_unit_cap:
+            return None
         try:
+            self.gold_units_launched += 1
             return self.get_gold_for_worker(worker)
         except Exception as e:
             logger.warning(f"Could not generate gold for {worker} due to {e}")
@@ -334,7 +370,9 @@ class UseGoldUnit(BlueprintMixin):
         return _wrapped_validate
 
     @classmethod
-    def get_mixin_qualifications(cls, args: "DictConfig"):
+    def get_mixin_qualifications(
+        cls, args: "DictConfig", shared_state: "SharedTaskState"
+    ):
         """Creates the relevant task qualifications for this task"""
         base_qual_name = args.blueprint.gold_qualification_base
         golds_failed_qual_name = f"{base_qual_name}-wrong-golds"
