@@ -9,12 +9,22 @@ from mephisto.abstractions.blueprint import (
     BlueprintArgs,
     SharedTaskState,
 )
+from dataclasses import dataclass, field
 from mephisto.abstractions.blueprints.mixins.onboarding_required import (
     OnboardingRequired,
     OnboardingSharedState,
     OnboardingRequiredArgs,
 )
-from dataclasses import dataclass, field
+from mephisto.abstractions.blueprints.mixins.screen_task_required import (
+    ScreenTaskRequired,
+    ScreenTaskRequiredArgs,
+    ScreenTaskSharedState,
+)
+from mephisto.abstractions.blueprints.mixins.use_gold_unit import (
+    UseGoldUnit,
+    UseGoldUnitArgs,
+    GoldUnitSharedState,
+)
 from mephisto.data_model.assignment import InitializationData
 from mephisto.abstractions.blueprints.remote_procedure.remote_procedure_agent_state import (
     RemoteProcedureAgentState,
@@ -53,7 +63,9 @@ BLUEPRINT_TYPE_REMOTE_PROCEDURE = "remote_procedure"
 
 
 @dataclass
-class SharedRemoteProcedureTaskState(OnboardingSharedState, SharedTaskState):
+class SharedRemoteProcedureTaskState(
+    ScreenTaskSharedState, OnboardingSharedState, GoldUnitSharedState, SharedTaskState
+):
     function_registry: Optional[
         Mapping[
             str,
@@ -67,7 +79,9 @@ class SharedRemoteProcedureTaskState(OnboardingSharedState, SharedTaskState):
 
 
 @dataclass
-class RemoteProcedureBlueprintArgs(OnboardingRequiredArgs, BlueprintArgs):
+class RemoteProcedureBlueprintArgs(
+    ScreenTaskRequiredArgs, OnboardingRequiredArgs, UseGoldUnitArgs, BlueprintArgs
+):
     _blueprint_type: str = BLUEPRINT_TYPE_REMOTE_PROCEDURE
     _group: str = field(
         default="RemoteProcedureBlueprintArgs",
@@ -105,7 +119,9 @@ class RemoteProcedureBlueprintArgs(OnboardingRequiredArgs, BlueprintArgs):
 
 
 @register_mephisto_abstraction()
-class RemoteProcedureBlueprint(OnboardingRequired, Blueprint):
+class RemoteProcedureBlueprint(
+    ScreenTaskRequired, OnboardingRequired, UseGoldUnit, Blueprint
+):
     """Blueprint for a task that runs a parlai chat"""
 
     AgentStateClass: ClassVar[Type["AgentState"]] = RemoteProcedureAgentState
