@@ -29,7 +29,6 @@ from mephisto.abstractions.blueprints.mixins.onboarding_required import (
 )
 from mephisto.abstractions.database import MephistoDB, EntryDoesNotExistException
 from mephisto.data_model.qualification import QUAL_NOT_EXIST
-from mephisto.tools.data_browser import DataBrowser as MephistoDataBrowser
 from mephisto.utils.qualifications import make_qualification_dict
 from mephisto.operations.task_launcher import TaskLauncher
 from mephisto.operations.client_io_handler import ClientIOHandler
@@ -56,7 +55,7 @@ from omegaconf import DictConfig, OmegaConf
 logger = get_logger(name=__name__)
 
 if TYPE_CHECKING:
-    from mephisto.abstractions.blueprint import Blueprint, TaskRunner
+    from mephisto.abstractions.blueprint import Blueprint
     from mephisto.abstractions.crowd_provider import CrowdProvider
     from mephisto.abstractions.architect import Architect
 
@@ -313,7 +312,7 @@ class Operator:
             raise e
 
         live_run.task_launcher.create_assignments()
-        live_run.task_launcher.launch_units(task_url)
+        live_run.task_launcher.launch_units(url=task_url)
 
         self._task_runs_tracked[task_run.db_id] = live_run
         task_run.update_completion_progress(status=False)
@@ -330,6 +329,13 @@ class Operator:
             runs_to_check = list(self._task_runs_tracked.values())
             for tracked_run in runs_to_check:
                 await asyncio.sleep(0.01)  # Low pri, allow to be interrupted
+                patience = tracked_run.task_run.get_task_args().no_submission_patience
+                if patience < time.time() - tracked_run.client_io.last_submission_time:
+                    logger.warn(
+                        f"It has been greater than the set no_submission_patience of {patience} "
+                        f"for {tracked_run.task_run} since the last submission, shutting this run down."
+                    )
+                    tracked_run.force_shutdown = True
                 if not tracked_run.force_shutdown:
                     task_run = tracked_run.task_run
                     if tracked_run.task_launcher.finished_generators is False:
@@ -345,6 +351,7 @@ class Operator:
                 tracked_run.client_io.shutdown()
                 tracked_run.worker_pool.shutdown()
                 tracked_run.task_launcher.shutdown()
+                tracked_run.task_launcher.expire_units()
                 tracked_run.architect.shutdown()
                 del self._task_runs_tracked[task_run.db_id]
             await asyncio.sleep(RUN_STATUS_POLL_TIME)
