@@ -265,13 +265,23 @@ class WorkerPool:
                     agent,
                 )
             else:
-                # See if the concurrent unit is ready to launch
                 assignment = await loop.run_in_executor(None, unit.get_assignment)
+
+                # Set status to waiting
+                agent.update_status(AgentState.STATUS_WAITING)
+
+                # See if the concurrent assignment is ready to launch
+                logger.debug(f"Attempting to launch {assignment}.")
                 agents = await loop.run_in_executor(None, assignment.get_agents)
                 if None in agents:
-                    agent.update_status(AgentState.STATUS_WAITING)
                     return  # need to wait for all agents to be here to launch
 
+                for queried_agent in agents:
+                    if queried_agent.get_status() != AgentState.STATUS_WAITING:
+                        logger.debug(f"Delaying launch of {assignment}, should retry.")
+                        return  # Need to wait for all agents to be waiting to launch
+
+                # Mypy not-null cast
                 non_null_agents = [a for a in agents if a is not None]
                 # Launch the backend for this assignment
                 registered_agents = [
@@ -460,6 +470,7 @@ class WorkerPool:
             function="get_valid_units_for_worker"
         ).time():
             units = task_run.get_valid_units_for_worker(worker)
+
         if len(units) == 0:
             AGENT_DETAILS_COUNT.labels(response="no_available_units").inc()
             live_run.client_io.enqueue_agent_details(
@@ -473,7 +484,6 @@ class WorkerPool:
                 f"agent_registration_id {agent_registration_id}, had no valid units."
             )
             return
-
         with EXTERNAL_FUNCTION_LATENCY.labels(
             function="filter_units_for_worker"
         ).time():
@@ -481,7 +491,6 @@ class WorkerPool:
                 None,
                 partial(live_run.task_runner.filter_units_for_worker, units, worker),
             )
-
         # If there's onboarding, see if this worker has already been disqualified
         blueprint = live_run.blueprint
         if isinstance(blueprint, OnboardingRequired) and blueprint.use_onboarding:
@@ -551,6 +560,7 @@ class WorkerPool:
                     onboard_agent, cleanup_onboarding
                 )
                 return
+
         if isinstance(blueprint, ScreenTaskRequired) and blueprint.use_screening_task:
             if (
                 blueprint.worker_needs_screening(worker)
