@@ -4,16 +4,14 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from mephisto.abstractions.database import MephistoDB
 from mephisto.data_model.unit import Unit
 from mephisto.data_model.task_run import TaskRun
-from mephisto.abstractions.blueprint import AgentState
-from mephisto.data_model.agent import Agent
+from mephisto.data_model.worker import Worker
 
 from mephisto.abstractions.databases.local_database import LocalMephistoDB
 from mephisto.data_model.constants.assignment_state import AssignmentState
 
-from typing import List, Optional, Any, Dict
+from typing import List, Any, Dict
 
 
 class DataBrowser:
@@ -27,10 +25,11 @@ class DataBrowser:
             db = LocalMephistoDB()
         self.db = db
 
-    def _get_units_for_task_runs(self, task_runs: List[TaskRun]) -> List[Unit]:
+    def collect_matching_units_from_task_runs(
+        self, task_runs: List[TaskRun], statuses: List[str]
+    ) -> List[Unit]:
         """
-        Return a list of all Units in a terminal completed state from all
-        the provided TaskRuns.
+        Loops through task_runs to collect all units in the provided statuses list
         """
         units = []
         for task_run in task_runs:
@@ -38,15 +37,27 @@ class DataBrowser:
             for assignment in assignments:
                 found_units = assignment.get_units()
                 for unit in found_units:
-                    if unit.get_status() in [
-                        AssignmentState.COMPLETED,
-                        AssignmentState.ACCEPTED,
-                        AssignmentState.REJECTED,
-                        AssignmentState.SOFT_REJECTED,
-                    ]:
+                    if unit.get_status() in statuses:
                         units.append(unit)
         return units
 
+    def _get_units_for_task_runs(self, task_runs: List[TaskRun]) -> List[Unit]:
+        """
+        Return a list of all Units in a terminal completed state from all
+        the provided TaskRuns.
+        """
+        return self.collect_matching_units_from_task_runs(
+            task_runs, AssignmentState.completed()
+        )
+
+    def _get_all_units_for_task_runs(self, task_runs: List[TaskRun]) -> List[Unit]:
+        """
+        Does the same as _get_units_for_task_runs except that it includes the EXPIRED state
+        """
+        return self.collect_matching_units_from_task_runs(
+            task_runs, AssignmentState.final_agent()
+        )
+
     def get_task_name_list(self) -> List[str]:
         return [task.task_name for task in self.db.find_tasks()]
 
@@ -60,6 +71,12 @@ class DataBrowser:
         task_runs = self.db.find_task_runs(task_id=tasks[0].db_id)
         return self._get_units_for_task_runs(task_runs)
 
+    def get_all_units_for_task_name(self, task_name: str) -> List[Unit]:
+        tasks = self.db.find_tasks(task_name=task_name)
+        assert len(tasks) >= 1, f"No task found under name {task_name}"
+        task_runs = self.db.find_task_runs(task_id=tasks[0].db_id)
+        return self._get_all_units_for_task_runs(task_runs)
+
     def get_units_for_run_id(self, run_id: str) -> List[Unit]:
         """
         Return a list of all Units in a terminal completed state from the
@@ -88,4 +105,40 @@ class DataBrowser:
             "data": agent.state.get_parsed_data(),
             "task_start": agent.state.get_task_start(),
             "task_end": agent.state.get_task_end(),
+            "tips": agent.state.get_tips(),
+            "feedback": agent.state.get_feedback(),
         }
+
+    def get_workers_with_qualification(self, qualification_name: str) -> List[Worker]:
+        """
+        Returns a list of 'Worker's for workers who are qualified wrt `qualification_name`.
+        """
+        qual_list = self.db.find_qualifications(qualification_name=qualification_name)
+        assert len(qual_list) >= 1, f"No qualification found named {qualification_name}"
+        qualification_id = qual_list[0].db_id
+        qualifieds = self.db.check_granted_qualifications(
+            qualification_id=qualification_id, value=1
+        )
+        return [Worker.get(self.db, qual.worker_id) for qual in qualifieds]
+
+    def get_metadata_property_from_task_name(
+        self, task_name: str, property_name: str
+    ) -> List[Any]:
+        """Returns all metadata for a task by going through its agents"""
+
+        units = self.get_all_units_for_task_name(task_name=task_name)
+        result: List[Any] = []
+
+        for unit in units:
+            if unit.agent_id is not None:
+                unit_data = self.get_data_from_unit(unit)
+
+                assert property_name in unit_data, (
+                    "The {property_name} field must exist in the unit's data. Look for {property_name} in the get_data_from_unit function"
+                ).format(property_name=property_name)
+
+                unit_property_val = unit_data[property_name]
+                if unit_property_val is not None:
+                    result = result + unit_property_val
+
+        return result
